@@ -42,8 +42,7 @@ ThemeConfigureDialog::ThemeConfigureDialog(QWidget *parent)
 
     QWidget *w = new QWidget;
 
-    QVBoxLayout *lay = new QVBoxLayout;
-    w->setLayout(lay);
+    QVBoxLayout *lay = new QVBoxLayout(w);
 
     mConfigureWidget = new GrantleeThemeEditor::ConfigureWidget;
     lay->addWidget(mConfigureWidget);
@@ -125,4 +124,3 @@ void ThemeConfigureDialog::writeConfig()
     group.writeEntry("defaultTemplate", mDefaultTemplate->toPlainText());
     mConfigureWidget->writeConfig();
 }
-
