@@ -21,11 +21,8 @@
 
 #include <PimCommon/TemplateListWidget>
 
-namespace ThemeDefaultTemplate
-{
-
+namespace ThemeDefaultTemplate {
 QVector<PimCommon::defaultTemplate> defaultTemplates();
-
 }
 
 #endif // THEMEDEFAULTTEMPLATE_H
